@@ -34,18 +34,16 @@ module type Either = sig
   type ('f, 's) t = ('f, 's) Either0.t =
     | First of 'f
     | Second of 's
-  [@@deriving_inline compare, hash, sexp]
+  [@@deriving_inline compare, hash, sexp, sexp_grammar]
 
-  val compare : ('f -> 'f -> int) -> ('s -> 's -> int) -> ('f, 's) t -> ('f, 's) t -> int
+  include Ppx_compare_lib.Comparable.S2 with type ('f, 's) t := ('f, 's) t
+  include Ppx_hash_lib.Hashable.S2 with type ('f, 's) t := ('f, 's) t
+  include Sexplib0.Sexpable.S2 with type ('f, 's) t := ('f, 's) t
 
-  val hash_fold_t
-    :  (Ppx_hash_lib.Std.Hash.state -> 'f -> Ppx_hash_lib.Std.Hash.state)
-    -> (Ppx_hash_lib.Std.Hash.state -> 's -> Ppx_hash_lib.Std.Hash.state)
-    -> Ppx_hash_lib.Std.Hash.state
-    -> ('f, 's) t
-    -> Ppx_hash_lib.Std.Hash.state
-
-  include Ppx_sexp_conv_lib.Sexpable.S2 with type ('f, 's) t := ('f, 's) t
+  val t_sexp_grammar
+    :  'f Sexplib0.Sexp_grammar.t
+    -> 's Sexplib0.Sexp_grammar.t
+    -> ('f, 's) t Sexplib0.Sexp_grammar.t
 
   [@@@end]
 
@@ -56,13 +54,7 @@ module type Either = sig
   val iter : ('a, 'b) t -> first:('a -> unit) -> second:('b -> unit) -> unit
   val value_map : ('a, 'b) t -> first:('a -> 'c) -> second:('b -> 'c) -> 'c
   val map : ('a, 'b) t -> first:('a -> 'c) -> second:('b -> 'd) -> ('c, 'd) t
-
-  val equal
-    :  ('f -> 'f -> bool)
-    -> ('s -> 's -> bool)
-    -> ('f, 's) t
-    -> ('f, 's) t
-    -> bool
+  val equal : ('f -> 'f -> bool) -> ('s -> 's -> bool) -> ('f, 's) t -> ('f, 's) t -> bool
 
   module type Focused = Focused
 
