@@ -12,37 +12,11 @@ let invalid_argf = Printf.invalid_argf
 module T = struct
   type 'a t = 'a list [@@deriving_inline sexp, sexp_grammar]
 
-  let t_of_sexp :
-    'a. (Ppx_sexp_conv_lib.Sexp.t -> 'a) -> Ppx_sexp_conv_lib.Sexp.t -> 'a t
-    =
-    list_of_sexp
-  ;;
+  let t_of_sexp : 'a. (Sexplib0.Sexp.t -> 'a) -> Sexplib0.Sexp.t -> 'a t = list_of_sexp
+  let sexp_of_t : 'a. ('a -> Sexplib0.Sexp.t) -> 'a t -> Sexplib0.Sexp.t = sexp_of_list
 
-  let sexp_of_t :
-    'a. ('a -> Ppx_sexp_conv_lib.Sexp.t) -> 'a t -> Ppx_sexp_conv_lib.Sexp.t
-    =
-    sexp_of_list
-  ;;
-
-  let (t_sexp_grammar : Ppx_sexp_conv_lib.Sexp.Private.Raw_grammar.t) =
-    let (_the_generic_group : Ppx_sexp_conv_lib.Sexp.Private.Raw_grammar.generic_group) =
-      { implicit_vars = [ "list" ]
-      ; ggid = "j\132);\135qH\158\135\222H\001\007\004\158\218"
-      ; types =
-          [ "t", Explicit_bind ([ "a" ], Apply (Implicit_var 0, [ Explicit_var 0 ])) ]
-      }
-    in
-    let (_the_group : Ppx_sexp_conv_lib.Sexp.Private.Raw_grammar.group) =
-      { gid = Ppx_sexp_conv_lib.Lazy_group_id.create ()
-      ; apply_implicit = [ list_sexp_grammar ]
-      ; generic_group = _the_generic_group
-      ; origin = "list.ml.T"
-      }
-    in
-    let (t_sexp_grammar : Ppx_sexp_conv_lib.Sexp.Private.Raw_grammar.t) =
-      Ref ("t", _the_group)
-    in
-    t_sexp_grammar
+  let (t_sexp_grammar : 'a Sexplib0.Sexp_grammar.t -> 'a t Sexplib0.Sexp_grammar.t) =
+    fun _'a_sexp_grammar -> list_sexp_grammar _'a_sexp_grammar
   ;;
 
   [@@@end]
@@ -55,25 +29,24 @@ module Or_unequal_lengths = struct
   [@@deriving_inline compare, sexp_of]
 
   let compare : 'a. ('a -> 'a -> int) -> 'a t -> 'a t -> int =
-    fun _cmp__a a__001_ b__002_ ->
-    if Ppx_compare_lib.phys_equal a__001_ b__002_
+    fun _cmp__a a__006_ b__007_ ->
+    if Ppx_compare_lib.phys_equal a__006_ b__007_
     then 0
     else (
-      match a__001_, b__002_ with
-      | Ok _a__003_, Ok _b__004_ -> _cmp__a _a__003_ _b__004_
+      match a__006_, b__007_ with
+      | Ok _a__008_, Ok _b__009_ -> _cmp__a _a__008_ _b__009_
       | Ok _, _ -> -1
       | _, Ok _ -> 1
       | Unequal_lengths, Unequal_lengths -> 0)
   ;;
 
-  let sexp_of_t
-    : type a. (a -> Ppx_sexp_conv_lib.Sexp.t) -> a t -> Ppx_sexp_conv_lib.Sexp.t
-    =
-    fun _of_a -> function
-      | Ok v0 ->
-        let v0 = _of_a v0 in
-        Ppx_sexp_conv_lib.Sexp.List [ Ppx_sexp_conv_lib.Sexp.Atom "Ok"; v0 ]
-      | Unequal_lengths -> Ppx_sexp_conv_lib.Sexp.Atom "Unequal_lengths"
+  let sexp_of_t : 'a. ('a -> Sexplib0.Sexp.t) -> 'a t -> Sexplib0.Sexp.t =
+    fun (type a__013_) : ((a__013_ -> Sexplib0.Sexp.t) -> a__013_ t -> Sexplib0.Sexp.t) ->
+    fun _of_a__010_ -> function
+      | Ok arg0__011_ ->
+        let res0__012_ = _of_a__010_ arg0__011_ in
+        Sexplib0.Sexp.List [ Sexplib0.Sexp.Atom "Ok"; res0__012_ ]
+      | Unequal_lengths -> Sexplib0.Sexp.Atom "Unequal_lengths"
   ;;
 
   [@@@end]
@@ -165,29 +138,82 @@ let unordered_append l1 l2 =
   | _ -> rev_append l1 l2
 ;;
 
-let check_length2_exn name l1 l2 =
-  let n1 = length l1 in
-  let n2 = length l2 in
-  if n1 <> n2 then invalid_argf "length mismatch in %s: %d <> %d" name n1 n2 ()
-;;
+module Check_length2 = struct
+  type ('a, 'b) t =
+    | Same_length of int
+    | Unequal_lengths of
+        { shared_length : int
+        ; tail_of_a : 'a list
+        ; tail_of_b : 'b list
+        }
 
-let check_length3_exn name l1 l2 l3 =
-  let n1 = length l1 in
-  let n2 = length l2 in
-  let n3 = length l3 in
-  if n1 <> n2 || n2 <> n3
-  then invalid_argf "length mismatch in %s: %d <> %d || %d <> %d" name n1 n2 n2 n3 ()
+  (* In the [Unequal_lengths] case, at least one of the tails will be non-empty. *)
+  let of_lists l1 l2 =
+    let rec loop a b shared_length =
+      match a, b with
+      | [], [] -> Same_length shared_length
+      | _ :: a, _ :: b -> loop a b (shared_length + 1)
+      | [], _ | _, [] -> Unequal_lengths { shared_length; tail_of_a = a; tail_of_b = b }
+    in
+    loop l1 l2 0
+  ;;
+end
+
+let check_length2_exn name l1 l2 =
+  match Check_length2.of_lists l1 l2 with
+  | Same_length _ -> ()
+  | Unequal_lengths { shared_length; tail_of_a; tail_of_b } ->
+    invalid_argf
+      "length mismatch in %s: %d <> %d"
+      name
+      (shared_length + length tail_of_a)
+      (shared_length + length tail_of_b)
+      ()
 ;;
 
 let check_length2 l1 l2 ~f =
-  if length l1 <> length l2 then Or_unequal_lengths.Unequal_lengths else Ok (f l1 l2)
+  match Check_length2.of_lists l1 l2 with
+  | Same_length _ -> Or_unequal_lengths.Ok (f l1 l2)
+  | Unequal_lengths _ -> Unequal_lengths
+;;
+
+module Check_length3 = struct
+  type ('a, 'b, 'c) t =
+    | Same_length of int
+    | Unequal_lengths of
+        { shared_length : int
+        ; tail_of_a : 'a list
+        ; tail_of_b : 'b list
+        ; tail_of_c : 'c list
+        }
+
+  (* In the [Unequal_lengths] case, at least one of the tails will be non-empty. *)
+  let of_lists l1 l2 l3 =
+    let rec loop a b c shared_length =
+      match a, b, c with
+      | [], [], [] -> Same_length shared_length
+      | _ :: a, _ :: b, _ :: c -> loop a b c (shared_length + 1)
+      | [], _, _ | _, [], _ | _, _, [] ->
+        Unequal_lengths { shared_length; tail_of_a = a; tail_of_b = b; tail_of_c = c }
+    in
+    loop l1 l2 l3 0
+  ;;
+end
+
+let check_length3_exn name l1 l2 l3 =
+  match Check_length3.of_lists l1 l2 l3 with
+  | Same_length _ -> ()
+  | Unequal_lengths { shared_length; tail_of_a; tail_of_b; tail_of_c } ->
+    let n1 = shared_length + length tail_of_a in
+    let n2 = shared_length + length tail_of_b in
+    let n3 = shared_length + length tail_of_c in
+    invalid_argf "length mismatch in %s: %d <> %d || %d <> %d" name n1 n2 n2 n3 ()
 ;;
 
 let check_length3 l1 l2 l3 ~f =
-  let n1 = length l1 in
-  let n2 = length l2 in
-  let n3 = length l3 in
-  if n1 <> n2 || n2 <> n3 then Or_unequal_lengths.Unequal_lengths else Ok (f l1 l2 l3)
+  match Check_length3.of_lists l1 l2 l3 with
+  | Same_length _ -> Or_unequal_lengths.Ok (f l1 l2 l3)
+  | Unequal_lengths _ -> Unequal_lengths
 ;;
 
 let iter2 l1 l2 ~f = check_length2 l1 l2 ~f:(iter2_ok ~f)
@@ -295,6 +321,16 @@ let findi t ~f =
   loop 0 t
 ;;
 
+let findi_exn =
+  let not_found = Not_found_s (Atom "List.findi_exn: not found") in
+  let findi_exn t ~f =
+    match findi t ~f with
+    | None -> raise not_found
+    | Some x -> x
+  in
+  findi_exn
+;;
+
 let find_mapi t ~f =
   let rec loop i t =
     match t with
@@ -342,9 +378,18 @@ let fold_left = fold
 let to_array = Array.of_list
 let to_list t = t
 
+let max_non_tailcall =
+  match Sys.backend_type with
+  | Sys.Native | Sys.Bytecode -> 1_000
+  (* We don't know the size of the stack, better be safe and assume it's small. This
+     number was taken from ocaml#stdlib/list.ml which is also equal to the default limit
+     of recursive call in the js_of_ocaml compiler before switching to trampoline. *)
+  | Sys.Other _ -> 50
+;;
+
 (** Tail recursive versions of standard [List] module *)
 
-let slow_append l1 l2 = rev_append (rev l1) l2
+let tail_append l1 l2 = rev_append (rev l1) l2
 
 (* There are a few optimized list operations here, including append and map.  There are
    basically two optimizations in play: loop unrolling, and dynamic switching between
@@ -374,11 +419,41 @@ let rec count_append l1 l2 count =
        :: x3
        :: x4
        :: x5
-       :: (if count > 1000 then slow_append tl l2 else count_append tl l2 (count + 1)))
+       ::
+       (if count > max_non_tailcall
+        then tail_append tl l2
+        else count_append tl l2 (count + 1)))
 ;;
 
 let append l1 l2 = count_append l1 l2 0
-let slow_map l ~f = rev (rev_map l ~f)
+
+(* An ordinary tail recursive map builds up an intermediate (reversed) representation,
+   with one heap allocated object per element. The following implementation instead chunks
+   9 objects into one heap allocated object, reducing allocation and performance costs
+   accordingly. Note that the very end of the list is done by the stdlib's map
+   function. *)
+let tail_map xs ~f =
+  let rec rise ys = function
+    | [] -> ys
+    | (y0, y1, y2, y3, y4, y5, y6, y7, y8) :: bs ->
+      rise (y0 :: y1 :: y2 :: y3 :: y4 :: y5 :: y6 :: y7 :: y8 :: ys) bs
+  in
+  let rec dive bs = function
+    | x0 :: x1 :: x2 :: x3 :: x4 :: x5 :: x6 :: x7 :: x8 :: xs ->
+      let y0 = f x0 in
+      let y1 = f x1 in
+      let y2 = f x2 in
+      let y3 = f x3 in
+      let y4 = f x4 in
+      let y5 = f x5 in
+      let y6 = f x6 in
+      let y7 = f x7 in
+      let y8 = f x8 in
+      dive ((y0, y1, y2, y3, y4, y5, y6, y7, y8) :: bs) xs
+    | xs -> rise (nontail_map ~f xs) bs
+  in
+  dive [] xs
+;;
 
 let rec count_map ~f l ctr =
   match l with
@@ -412,7 +487,7 @@ let rec count_map ~f l ctr =
     :: f3
     :: f4
     :: f5
-    :: (if ctr > 1000 then slow_map ~f tl else count_map ~f tl (ctr + 1))
+    :: (if ctr > max_non_tailcall then tail_map ~f tl else count_map ~f tl (ctr + 1))
 ;;
 
 let map l ~f = count_map ~f l 0
@@ -476,33 +551,27 @@ let rec rev_map_append l1 l2 ~f =
   | h :: t -> rev_map_append ~f t (f h :: l2)
 ;;
 
-let fold_right l ~f ~init =
-  match l with
-  | [] -> init (* avoid the allocation of [~f] below *)
-  | _ -> fold ~f:(fun a b -> f b a) ~init (rev l)
-;;
-
 let unzip list =
   let rec loop list l1 l2 =
     match list with
-    | [] -> rev l1, rev l2
+    | [] -> l1, l2
     | (x, y) :: tl -> loop tl (x :: l1) (y :: l2)
   in
-  loop list [] []
+  loop (rev list) [] []
 ;;
 
 let unzip3 list =
   let rec loop list l1 l2 l3 =
     match list with
-    | [] -> rev l1, rev l2, rev l3
+    | [] -> l1, l2, l3
     | (x, y, z) :: tl -> loop tl (x :: l1) (y :: l2) (z :: l3)
   in
-  loop list [] [] []
+  loop (rev list) [] [] []
 ;;
 
 let zip_exn l1 l2 =
-  check_length2_exn "zip_exn" l1 l2;
-  map2_ok ~f:(fun a b -> a, b) l1 l2
+  try map2_ok ~f:(fun a b -> a, b) l1 l2 with
+  | _ -> invalid_argf "length mismatch in zip_exn: %d <> %d" (length l1) (length l2) ()
 ;;
 
 let zip l1 l2 = map2 ~f:(fun a b -> a, b) l1 l2
@@ -630,6 +699,10 @@ let groupi l ~break =
 
 let group l ~break = groupi l ~break:(fun _ x y -> break x y)
 
+let sort_and_group l ~compare =
+  l |> stable_sort ~compare |> group ~break:(fun x y -> compare x y <> 0)
+;;
+
 let concat_map l ~f =
   let rec aux acc = function
     | [] -> rev acc
@@ -657,30 +730,77 @@ let merge l1 l2 ~compare =
   loop [] l1 l2
 ;;
 
-include struct
-  (* We are explicit about what we import from the general Monad functor so that we don't
-     accidentally rebind more efficient list-specific functions. *)
-  module Monad = Monad.Make (struct
-      type 'a t = 'a list
+module Cartesian_product = struct
+  (* We are explicit about what we export from functors so that we don't accidentally
+     rebind more efficient list-specific functions. *)
 
-      let bind x ~f = concat_map x ~f
-      let map = `Custom map
-      let return x = [ x ]
-    end)
-
-  open Monad
-  module Monad_infix = Monad_infix
-  module Let_syntax = Let_syntax
-
-  let ignore_m = ignore_m
-  let join = join
-  let bind = bind
+  let bind = concat_map
+  let map = map
+  let map2 a b ~f = concat_map a ~f:(fun x -> map b ~f:(fun y -> f x y))
+  let return x = [ x ]
+  let ( >>| ) = ( >>| )
   let ( >>= ) t f = bind t ~f
-  let return = return
-  let all = all
-  let all_unit = all_unit
+
+  open struct
+    module Applicative = Applicative.Make_using_map2 (struct
+        type 'a t = 'a list
+
+        let return = return
+        let map = `Custom map
+        let map2 = map2
+      end)
+
+    module Monad = Monad.Make (struct
+        type 'a t = 'a list
+
+        let return = return
+        let map = `Custom map
+        let bind = bind
+      end)
+  end
+
+  let all = Monad.all
+  let all_unit = Monad.all_unit
+  let ignore_m = Monad.ignore_m
+  let join = Monad.join
+
+  module Monad_infix = struct
+    let ( >>| ) = ( >>| )
+    let ( >>= ) = ( >>= )
+  end
+
+  let apply = Applicative.apply
+  let both = Applicative.both
+  let map3 = Applicative.map3
+  let ( <*> ) = Applicative.( <*> )
+  let ( *> ) = Applicative.( *> )
+  let ( <* ) = Applicative.( <* )
+
+  module Applicative_infix = struct
+    let ( >>| ) = ( >>| )
+    let ( <*> ) = Applicative.( <*> )
+    let ( *> ) = Applicative.( *> )
+    let ( <* ) = Applicative.( <* )
+  end
+
+  module Let_syntax = struct
+    let return = return
+    let ( >>| ) = ( >>| )
+    let ( >>= ) = ( >>= )
+
+    module Let_syntax = struct
+      let return = return
+      let bind = bind
+      let map = map
+      let both = both
+
+      module Open_on_rhs = struct end
+    end
+  end
 end
 
+include (Cartesian_product : Monad.S with type 'a t := 'a t)
+
 (** returns final element of list *)
 let rec last_exn list =
   match list with
@@ -739,7 +859,7 @@ let remove_consecutive_duplicates ?(which_to_keep = `Last) list ~equal =
 ;;
 
 (** returns sorted version of list with duplicates removed *)
-let dedup_and_sort ~compare list =
+let dedup_and_sort list ~compare =
   match list with
   | [] | [ _ ] -> list (* performance hack *)
   | _ ->
@@ -748,8 +868,8 @@ let dedup_and_sort ~compare list =
     remove_consecutive_duplicates ~equal sorted
 ;;
 
-let find_a_dup ~compare l =
-  let sorted = sort ~compare l in
+let find_a_dup l ~compare =
+  let sorted = sort l ~compare in
   let rec loop l =
     match l with
     | [] | [ _ ] -> None
@@ -758,13 +878,13 @@ let find_a_dup ~compare l =
   loop sorted
 ;;
 
-let contains_dup ~compare lst =
-  match find_a_dup ~compare lst with
+let contains_dup lst ~compare =
+  match find_a_dup lst ~compare with
   | Some _ -> true
   | None -> false
 ;;
 
-let find_all_dups ~compare l =
+let find_all_dups l ~compare =
   (* We add this reversal, so we can skip a [rev] at the end. We could skip
      [rev] anyway since we don not give any ordering guarantees, but it is
      nice to get results in natural order. *)
@@ -786,6 +906,18 @@ let find_all_dups ~compare l =
   | hd :: tl -> loop tl hd ~already_recorded:false []
 ;;
 
+let rec all_equal_to t v ~equal =
+  match t with
+  | [] -> true
+  | x :: xs -> equal x v && all_equal_to xs v ~equal
+;;
+
+let all_equal t ~equal =
+  match t with
+  | [] -> None
+  | x :: xs -> if all_equal_to xs x ~equal then Some x else None
+;;
+
 let count t ~f = Container.count ~fold t ~f
 let sum m t ~f = Container.sum ~fold m t ~f
 let min_elt t ~compare = Container.min_elt ~fold t ~compare
@@ -854,40 +986,75 @@ let partition_tf t ~f =
 let partition_result t = partition_map t ~f:Result.to_either
 
 module Assoc = struct
-  type ('a, 'b) t = ('a * 'b) list [@@deriving_inline sexp]
+  type ('a, 'b) t = ('a * 'b) list [@@deriving_inline sexp, sexp_grammar]
 
   let t_of_sexp :
-    'a 'b. (Ppx_sexp_conv_lib.Sexp.t -> 'a) -> (Ppx_sexp_conv_lib.Sexp.t -> 'b)
-    -> Ppx_sexp_conv_lib.Sexp.t -> ('a, 'b) t
+    'a 'b.
+    (Sexplib0.Sexp.t -> 'a)
+    -> (Sexplib0.Sexp.t -> 'b)
+    -> Sexplib0.Sexp.t
+    -> ('a, 'b) t
     =
-    let _tp_loc = "list.ml.Assoc.t" in
-    fun _of_a _of_b t ->
+    let error_source__022_ = "list.ml.Assoc.t" in
+    fun _of_a__014_ _of_b__015_ x__023_ ->
       list_of_sexp
         (function
-          | Ppx_sexp_conv_lib.Sexp.List [ v0; v1 ] ->
-            let v0 = _of_a v0
-            and v1 = _of_b v1 in
-            v0, v1
-          | sexp -> Ppx_sexp_conv_lib.Conv_error.tuple_of_size_n_expected _tp_loc 2 sexp)
-        t
+          | Sexplib0.Sexp.List [ arg0__017_; arg1__018_ ] ->
+            let res0__019_ = _of_a__014_ arg0__017_
+            and res1__020_ = _of_b__015_ arg1__018_ in
+            res0__019_, res1__020_
+          | sexp__021_ ->
+            Sexplib0.Sexp_conv_error.tuple_of_size_n_expected
+              error_source__022_
+              2
+              sexp__021_)
+        x__023_
   ;;
 
   let sexp_of_t :
-    'a 'b. ('a -> Ppx_sexp_conv_lib.Sexp.t) -> ('b -> Ppx_sexp_conv_lib.Sexp.t)
-    -> ('a, 'b) t -> Ppx_sexp_conv_lib.Sexp.t
+    'a 'b.
+    ('a -> Sexplib0.Sexp.t)
+    -> ('b -> Sexplib0.Sexp.t)
+    -> ('a, 'b) t
+    -> Sexplib0.Sexp.t
     =
-    fun _of_a _of_b v ->
+    fun _of_a__024_ _of_b__025_ x__030_ ->
       sexp_of_list
-        (function
-          | v0, v1 ->
-            let v0 = _of_a v0
-            and v1 = _of_b v1 in
-            Ppx_sexp_conv_lib.Sexp.List [ v0; v1 ])
-        v
+        (fun (arg0__026_, arg1__027_) ->
+           let res0__028_ = _of_a__024_ arg0__026_
+           and res1__029_ = _of_b__025_ arg1__027_ in
+           Sexplib0.Sexp.List [ res0__028_; res1__029_ ])
+        x__030_
+  ;;
+
+  let (t_sexp_grammar :
+         'a Sexplib0.Sexp_grammar.t
+       -> 'b Sexplib0.Sexp_grammar.t
+       -> ('a, 'b) t Sexplib0.Sexp_grammar.t)
+    =
+    fun _'a_sexp_grammar _'b_sexp_grammar ->
+      list_sexp_grammar
+        { untyped =
+            List (Cons (_'a_sexp_grammar.untyped, Cons (_'b_sexp_grammar.untyped, Empty)))
+        }
   ;;
 
   [@@@end]
 
+  let pair_of_group = function
+    | [] -> assert false
+    | (k, _) :: _ as list -> k, map list ~f:snd
+  ;;
+
+  let group alist ~equal =
+    group alist ~break:(fun (x, _) (y, _) -> not (equal x y)) |> map ~f:pair_of_group
+  ;;
+
+  let sort_and_group alist ~compare =
+    sort_and_group alist ~compare:(fun (x, _) (y, _) -> compare x y)
+    |> map ~f:pair_of_group
+  ;;
+
   let find t ~equal key =
     match find t ~f:(fun (key', _) -> equal key key') with
     | None -> None
@@ -969,8 +1136,7 @@ let rec drop t n =
 ;;
 
 let chunks_of l ~length =
-  if length <= 0
-  then invalid_argf "List.chunks_of: Expected length > 0, got %d" length ();
+  if length <= 0 then invalid_argf "List.chunks_of: Expected length > 0, got %d" length ();
   let rec aux of_length acc l =
     match l with
     | [] -> rev acc
@@ -1099,33 +1265,38 @@ let equal equal t1 t2 =
 ;;
 
 let transpose =
-  let rec transpose_aux t rev_columns =
-    match
-      partition_map t ~f:(function
-        | [] -> Second ()
-        | x :: xs -> First (x, xs))
-    with
-    | _ :: _, _ :: _ -> None
-    | [], _ -> Some (rev_append rev_columns [])
-    | heads_and_tails, [] ->
-      let column, trimmed_rows = unzip heads_and_tails in
-      transpose_aux trimmed_rows (column :: rev_columns)
+  let rec split_off_first_column t column_acc trimmed found_empty =
+    match t with
+    | [] -> column_acc, trimmed, found_empty
+    | [] :: tl -> split_off_first_column tl column_acc trimmed true
+    | (x :: xs) :: tl ->
+      split_off_first_column tl (x :: column_acc) (xs :: trimmed) found_empty
   in
-  fun t -> transpose_aux t []
+  let split_off_first_column rows = split_off_first_column rows [] [] false in
+  let rec loop rows columns do_rev =
+    match split_off_first_column rows with
+    | [], [], _ -> Some (rev columns)
+    | column, trimmed_rows, found_empty ->
+      if found_empty
+      then None
+      else (
+        let column = if do_rev then rev column else column in
+        loop trimmed_rows (column :: columns) (not do_rev))
+  in
+  fun t -> loop t [] true
 ;;
 
 exception Transpose_got_lists_of_different_lengths of int list [@@deriving_inline sexp]
 
 let () =
-  Ppx_sexp_conv_lib.Conv.Exn_converter.add
+  Sexplib0.Sexp_conv.Exn_converter.add
     [%extension_constructor Transpose_got_lists_of_different_lengths]
     (function
-      | Transpose_got_lists_of_different_lengths v0 ->
-        let v0 = sexp_of_list sexp_of_int v0 in
-        Ppx_sexp_conv_lib.Sexp.List
-          [ Ppx_sexp_conv_lib.Sexp.Atom
-              "list.ml.Transpose_got_lists_of_different_lengths"
-          ; v0
+      | Transpose_got_lists_of_different_lengths arg0__031_ ->
+        let res0__032_ = sexp_of_list sexp_of_int arg0__031_ in
+        Sexplib0.Sexp.List
+          [ Sexplib0.Sexp.Atom "list.ml.Transpose_got_lists_of_different_lengths"
+          ; res0__032_
           ]
       | _ -> assert false)
 ;;
