@@ -9,18 +9,15 @@
 open! Import
 
 (** Serialization and comparison of an [Error] force the error's lazy message. *)
-type 'a t = ('a, Error.t) Result.t [@@deriving_inline compare, equal, hash, sexp]
+type 'a t = ('a, Error.t) Result.t
+[@@deriving_inline compare, equal, hash, sexp, sexp_grammar]
 
-val compare : ('a -> 'a -> int) -> 'a t -> 'a t -> int
-val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
+include Ppx_compare_lib.Comparable.S1 with type 'a t := 'a t
+include Ppx_compare_lib.Equal.S1 with type 'a t := 'a t
+include Ppx_hash_lib.Hashable.S1 with type 'a t := 'a t
+include Sexplib0.Sexpable.S1 with type 'a t := 'a t
 
-val hash_fold_t
-  :  (Ppx_hash_lib.Std.Hash.state -> 'a -> Ppx_hash_lib.Std.Hash.state)
-  -> Ppx_hash_lib.Std.Hash.state
-  -> 'a t
-  -> Ppx_hash_lib.Std.Hash.state
-
-include Ppx_sexp_conv_lib.Sexpable.S1 with type 'a t := 'a t
+val t_sexp_grammar : 'a Sexplib0.Sexp_grammar.t -> 'a t Sexplib0.Sexp_grammar.t
 
 [@@@end]
 
@@ -28,8 +25,7 @@ include Ppx_sexp_conv_lib.Sexpable.S1 with type 'a t := 'a t
     [Applicative.Of_Monad(Or_error)] would give -- [apply (Error e1) (Error e2)] returns
     the combination of [e1] and [e2], whereas it would only return [e1] if it were defined
     using [bind]. *)
-include
-  Applicative.S with type 'a t := 'a t
+include Applicative.S with type 'a t := 'a t
 
 include Invariant.S1 with type 'a t := 'a t
 include Monad.S with type 'a t := 'a t
@@ -72,7 +68,13 @@ val of_exn_result : ?backtrace:[ `Get | `This of string ] -> ('a, exn) Result.t
     to a sexp.  So, if [a] is mutated in the time between the call to [create] and the
     sexp conversion, those mutations will be reflected in the sexp.  Use [~strict:()] to
     force [sexp_of_a a] to be computed immediately. *)
-val error : ?strict:unit -> string -> 'a -> ('a -> Sexp.t) -> _ t
+val error
+  :  ?here:Source_code_position0.t
+  -> ?strict:unit
+  -> string
+  -> 'a
+  -> ('a -> Sexp.t)
+  -> _ t
 
 val error_s : Sexp.t -> _ t
 
@@ -84,11 +86,16 @@ val error_string : string -> _ t
     instead. *)
 val errorf : ('a, unit, string, _ t) format4 -> 'a
 
-(** [tag t ~tag] is [Result.map_error t ~f:(Error.tag ~tag)].
-    [tag_arg] is similar. *)
+(** [tag t ~tag] is [Result.map_error t ~f:(Error.tag ~tag)]. *)
 val tag : 'a t -> tag:string -> 'a t
 
+(** [tag_s] is like [tag] with a sexp tag. *)
 val tag_s : 'a t -> tag:Sexp.t -> 'a t
+
+(** [tag_s_lazy] is like [tag] with a lazy sexp tag. *)
+val tag_s_lazy : 'a t -> tag:Sexp.t Lazy.t -> 'a t
+
+(** [tag_arg] is like [tag], with a tag that has a sexpable argument. *)
 val tag_arg : 'a t -> string -> 'b -> ('b -> Sexp.t) -> 'a t
 
 (** For marking a given value as unimplemented.  Typically combined with conditional
